==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01Builder extends ACMEChallengeSolverHTTP01FluentImpl<ACMEChallengeSolverHTTP01Builder> implements VisitableBuilder<ACMEChallengeSolverHTTP01,ACMEChallengeSolverHTTP01Builder>{
  public ACMEChallengeSolverHTTP01Builder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01Builder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,ACMEChallengeSolverHTTP01 instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,ACMEChallengeSolverHTTP01 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      fluent.withIngress(instance.getIngress());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01 instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01 instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      this.withIngress(instance.getIngress());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01 build() {
    ACMEChallengeSolverHTTP01 buildable = new ACMEChallengeSolverHTTP01(fluent.getGatewayHTTPRoute(),fluent.getIngress());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01Builder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01Builder extends ACMEChallengeSolverHTTP01Fluent<ACMEChallengeSolverHTTP01Builder> implements VisitableBuilder<ACMEChallengeSolverHTTP01,ACMEChallengeSolverHTTP01Builder>{
  public ACMEChallengeSolverHTTP01Builder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01Builder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,ACMEChallengeSolverHTTP01 instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01Fluent<?> fluent,ACMEChallengeSolverHTTP01 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01());

    if (instance != null) {
      fluent.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      fluent.withIngress(instance.getIngress());
      fluent.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      fluent.withIngress(instance.getIngress());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01 instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01Builder(ACMEChallengeSolverHTTP01 instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01());

    if (instance != null) {
      this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      this.withIngress(instance.getIngress());
      this.withGatewayHTTPRoute(instance.getGatewayHTTPRoute());
      this.withIngress(instance.getIngress());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01Fluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01 build() {
    ACMEChallengeSolverHTTP01 buildable = new ACMEChallengeSolverHTTP01(fluent.buildGatewayHTTPRoute(),fluent.buildIngress());
    return buildable;
  }
  
}
